From 62c97f711d01fe16c1fed5822c2bab1374eade32 Mon Sep 17 00:00:00 2001
From: Alyssa Rosenzweig <alyssa@rosenzweig.io>
Date: Tue, 22 Mar 2022 13:39:10 -0400
Subject: [PATCH] macsmd-hid: Respond to power button on Mini

On an M1 Mac Mini with 12.3 system firmware, the initial tap of the
power button is reported as button 0x01 rather than 0x06. Handle both
button IDs as power buttons. With this change, tapping the power button
on the Mini correctly triggers the power off dialog in GNOME and
triggers an immediate shutdown in fbcon, like the power button does on
other Linux machines as well as presumably the M1 MacBooks.

Signed-off-by: Alyssa Rosenzweig <alyssa@rosenzweig.io>
---
 drivers/input/misc/macsmc-hid.c | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/drivers/input/misc/macsmc-hid.c b/drivers/input/misc/macsmc-hid.c
index c4c7440d4ee6..dca306785d36 100644
--- a/drivers/input/misc/macsmc-hid.c
+++ b/drivers/input/misc/macsmc-hid.c
@@ -24,7 +24,8 @@ struct macsmc_hid {
 #define SMC_EV_BTN 0x7201
 #define SMC_EV_LID 0x7203
 
-#define BTN_POWER	0x06
+#define BTN_POWER	0x01
+#define BTN_POWER_ALT	0x06
 #define BTN_POWER_HELD1	0xfe
 #define BTN_POWER_HELD2	0x00
 
@@ -39,6 +40,7 @@ static int macsmc_hid_event(struct notifier_block *nb, unsigned long event, void
 	case SMC_EV_BTN:
 		switch (d1) {
 		case BTN_POWER:
+		case BTN_POWER_ALT:
 			if (smchid->wakeup_mode) {
 				if (d2) {
 					dev_info(smchid->dev, "Button wakeup\n");
-- 
2.30.2

